# Generated by Plain 0.127.2 on 2026-03-25 16:53

from plain.postgres import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("plainjobs", "0008_alter_jobrequest_options"),
    ]

    operations = [
        migrations.RemoveIndex(
            model_name="jobprocess",
            name="plainjobs_j_job_cla_19f3c1_idx",
        ),
        migrations.RemoveIndex(
            model_name="jobrequest",
            name="plainjobs_j_job_cla_a18abf_idx",
        ),
    ]
