# Generated by Plain 0.52.2 on 2025-07-17 19:33

from plain import postgres
from plain.postgres import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("plainjobs", "0001_initial"),
    ]

    operations = [
        migrations.AddField(
            model_name="job",
            name="span_id",
            field=postgres.CharField(allow_null=True, max_length=18, required=False),
        ),
        migrations.AddField(
            model_name="job",
            name="trace_id",
            field=postgres.CharField(allow_null=True, max_length=34, required=False),
        ),
        migrations.AddField(
            model_name="jobrequest",
            name="span_id",
            field=postgres.CharField(allow_null=True, max_length=18, required=False),
        ),
        migrations.AddField(
            model_name="jobrequest",
            name="trace_id",
            field=postgres.CharField(allow_null=True, max_length=34, required=False),
        ),
        migrations.AddField(
            model_name="jobresult",
            name="span_id",
            field=postgres.CharField(allow_null=True, max_length=18, required=False),
        ),
        migrations.AddField(
            model_name="jobresult",
            name="trace_id",
            field=postgres.CharField(allow_null=True, max_length=34, required=False),
        ),
        migrations.AddIndex(
            model_name="job",
            index=postgres.Index(
                fields=["trace_id"], name="plainworker_trace_i_d2b645_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="jobrequest",
            index=postgres.Index(
                fields=["trace_id"], name="plainworker_trace_i_e9dfc5_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="jobresult",
            index=postgres.Index(
                fields=["trace_id"], name="plainworker_trace_i_00c75f_idx"
            ),
        ),
    ]
