# Generated by Plain 0.127.2 on 2026-03-25 20:19

from plain.postgres import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("plainjobs", "0009_remove_jobprocess_plainjobs_j_job_cla_19f3c1_idx_and_more"),
    ]

    operations = [
        migrations.RenameIndex(
            model_name="jobprocess",
            new_name="plainjobs_jobprocess_created_at_idx",
            old_name="plainjobs_j_created_04fbb8_idx",
        ),
        migrations.RenameIndex(
            model_name="jobprocess",
            new_name="plainjobs_jobprocess_queue_idx",
            old_name="plainjobs_j_queue_d07d21_idx",
        ),
        migrations.RenameIndex(
            model_name="jobprocess",
            new_name="plainjobs_jobprocess_concurrency_key_idx",
            old_name="plainjobs_j_concurr_ad4464_idx",
        ),
        migrations.RenameIndex(
            model_name="jobprocess",
            new_name="plainjobs_jobprocess_started_at_idx",
            old_name="plainjobs_j_started_5cd62a_idx",
        ),
        migrations.RenameIndex(
            model_name="jobprocess",
            new_name="plainjobs_jobprocess_job_request_uuid_idx",
            old_name="plainjobs_j_job_req_32b6eb_idx",
        ),
        migrations.RenameIndex(
            model_name="jobprocess",
            new_name="plainjobs_jobprocess_trace_id_idx",
            old_name="plainjobs_j_trace_i_9f93c8_idx",
        ),
        migrations.RenameIndex(
            model_name="jobprocess",
            new_name="plainjobs_jobprocess_uuid_idx",
            old_name="plainjobs_j_uuid_cd8cd3_idx",
        ),
        migrations.RenameIndex(
            model_name="jobrequest",
            new_name="plainjobs_jobrequest_priority_idx",
            old_name="plainjobs_j_priorit_fd4fac_idx",
        ),
        migrations.RenameIndex(
            model_name="jobrequest",
            new_name="plainjobs_jobrequest_created_at_idx",
            old_name="plainjobs_j_created_1eeb20_idx",
        ),
        migrations.RenameIndex(
            model_name="jobrequest",
            new_name="plainjobs_jobrequest_queue_idx",
            old_name="plainjobs_j_queue_b34b5a_idx",
        ),
        migrations.RenameIndex(
            model_name="jobrequest",
            new_name="plainjobs_jobrequest_start_at_idx",
            old_name="plainjobs_j_start_a_f3b8da_idx",
        ),
        migrations.RenameIndex(
            model_name="jobrequest",
            new_name="plainjobs_jobrequest_concurrency_key_idx",
            old_name="plainjobs_j_concurr_c10926_idx",
        ),
        migrations.RenameIndex(
            model_name="jobrequest",
            new_name="plainjobs_jobrequest_trace_id_idx",
            old_name="plainjobs_j_trace_i_194003_idx",
        ),
        migrations.RenameIndex(
            model_name="jobrequest",
            new_name="plainjobs_jobrequest_uuid_idx",
            old_name="plainjobs_j_uuid_c41c85_idx",
        ),
        migrations.RenameIndex(
            model_name="jobresult",
            new_name="plainjobs_jobresult_created_at_idx",
            old_name="plainjobs_j_created_7978bf_idx",
        ),
        migrations.RenameIndex(
            model_name="jobresult",
            new_name="plainjobs_jobresult_job_process_uuid_idx",
            old_name="plainjobs_j_job_pro_751a64_idx",
        ),
        migrations.RenameIndex(
            model_name="jobresult",
            new_name="plainjobs_jobresult_started_at_idx",
            old_name="plainjobs_j_started_6fb2ce_idx",
        ),
        migrations.RenameIndex(
            model_name="jobresult",
            new_name="plainjobs_jobresult_ended_at_idx",
            old_name="plainjobs_j_ended_a_648f25_idx",
        ),
        migrations.RenameIndex(
            model_name="jobresult",
            new_name="plainjobs_jobresult_status_idx",
            old_name="plainjobs_j_status_1ef683_idx",
        ),
        migrations.RenameIndex(
            model_name="jobresult",
            new_name="plainjobs_jobresult_job_request_uuid_idx",
            old_name="plainjobs_j_job_req_3ddecf_idx",
        ),
        migrations.RenameIndex(
            model_name="jobresult",
            new_name="plainjobs_jobresult_job_class_idx",
            old_name="plainjobs_j_job_cla_8791b4_idx",
        ),
        migrations.RenameIndex(
            model_name="jobresult",
            new_name="plainjobs_jobresult_queue_idx",
            old_name="plainjobs_j_queue_0a2178_idx",
        ),
        migrations.RenameIndex(
            model_name="jobresult",
            new_name="plainjobs_jobresult_trace_id_idx",
            old_name="plainjobs_j_trace_i_02f370_idx",
        ),
        migrations.RenameIndex(
            model_name="jobresult",
            new_name="plainjobs_jobresult_uuid_idx",
            old_name="plainjobs_j_uuid_b33b4c_idx",
        ),
    ]
